@@ -27,8 +27,9 @@ latex_warnfile = StringIO()
 
 ENV_WARNINGS = """\
 WARNING: %(root)s/images.txt:9: Image file not readable: foo.png
-WARNING: %(root)s/images.txt:20: Nonlocal image URI found: http://www.python.org/logo.png
-WARNING: %(root)s/includes.txt:: (WARNING/2) Encoding 'utf-8' used for reading included file u'wrongenc.inc' seems to be wrong, try giving an :encoding: option
+WARNING: %(root)s/images.txt:21: Nonlocal image URI found: http://www.python.org/logo.png
+WARNING: %(root)s/includes.txt:: (WARNING/2) Encoding 'utf-8' used for reading included \
+file u'wrongenc.inc' seems to be wrong, try giving an :encoding: option
 """
 
 HTML_WARNINGS = ENV_WARNINGS + """\
@@ -43,11 +44,37 @@ HTML_XPATH = {
     'images.html': {
         ".//img[@src='_images/img.png']": '',
         ".//img[@src='_images/img1.png']": '',
+        ".//img[@src='_images/simg.png']": '',
     },
     'includes.html': {
         ".//pre/span[@class='s']": u'üöä',
         ".//pre": u'Max Strauß',
     },
+    'autodoc.html': {
+        ".//dt[@id='test_autodoc.Class']": '',
+        ".//dt[@id='test_autodoc.function']/em": '**kwds',
+        ".//dd": 'Return spam.',
+    },
+    'markup.html': {
+        ".//meta[@name='author'][@content='Me']": '',
+        ".//meta[@name='keywords'][@content='docs, sphinx']": '',
+        ".//a[@href='contents.html#ref1']": '',
+        ".//div[@id='label']": '',
+        ".//span[@class='option']": '--help',
+    },
+    'desc.html': {
+        ".//dt[@id='mod.Cls.meth1']": '',
+        ".//dt[@id='errmod.Error']": '',
+        ".//a[@href='#mod.Cls']": '',
+    },
+    'contents.html': {
+        ".//meta[@name='hc'][@content='hcval']": '',
+        ".//td[@class='label']": '[Ref1]',
+        ".//li[@class='toctree-l1']/a": 'Testing various markup',
+        ".//li[@class='toctree-l2']/a": 'Admonitions',
+        ".//title": 'Sphinx <Tests>',
+        ".//div[@class='footer']": 'Georg Brandl & Team',
+    },
 }
 
 class NslessParser(ET.XMLParser):
@@ -74,8 +101,6 @@ def test_html(app):
            '\n'.join(difflib.ndiff(html_warnings_exp.splitlines(),
                                    html_warnings.splitlines()))
 
-    if not ET:
-        return
     for fname, paths in HTML_XPATH.iteritems():
         parser = NslessParser()
         parser.entity.update(htmlentitydefs.entitydefs)
