@@ -94,7 +94,7 @@ def test_inline():
     # non-interpolation of dashes in option role
     verify_re(':option:`--with-option`',
               '<p><em( class="xref")?>--with-option</em></p>$',
-              r'\\emph{\\texttt{--with-option}}$')
+              r'\\emph{\\texttt{-{-}with-option}}$')
 
     # verify smarty-pants quotes
     verify('"John"', '<p>&#8220;John&#8221;</p>', "``John''")
@@ -110,5 +110,5 @@ def test_latex_escaping():
     # in verbatim code fragments
     verify(u'::\n\n @Γ\\∞$[]', None,
            u'\\begin{Verbatim}[commandchars=@\\[\\]]\n'
-           u'@at[]@(@Gamma@)\\@(@infty@)@$@lb[]@rb[]\n'
+           u'@PYGZat[]@(@Gamma@)\\@(@infty@)@$@PYGZlb[]@PYGZrb[]\n'
            u'\\end{Verbatim}')
